pub enum Discriminator {
Known(VariantId),
Invalid,
Branch {
offset: OffsetExpr,
int_ty: IntegerTy,
children: Vec<(RangeInclusive<IntegerValue>, Discriminator)>,
fallback: Box<Discriminator>,
},
}Expand description
Decision tree used to determine the active variant by reading memory. Mirrors MiniRust’s
Discriminator.
Variants
Known(VariantId)
The variant is known.
Invalid
No valid variant (e.g., invalid tag value).
Branch
Branch on an integer value read from memory at offset.
Fields

offset: OffsetExprByte offset to read from.

children: Vec<(RangeInclusive<IntegerValue>, Discriminator)>If the integer is in one of these ranges, continue with the given Discriminator. The
ranges are sorted.

fallback: Box<Discriminator>Fallback if no range in children matches.
Implementations
Sourceimpl Discriminator
impl Discriminator
Sourcepub fn trivial(variant_id: VariantId) -> Self
pub fn trivial(variant_id: VariantId) -> Self
Make a trivial discriminator that always returns the given variant id.
Sourcepub fn read_discriminant(
&self,
read: impl Fn(ByteCount, IntegerTy) -> Result<IntegerValue, DiscriminantReadError> + Copy,
) -> Result<VariantId, DiscriminantReadError>
pub fn read_discriminant( &self, read: impl Fn(ByteCount, IntegerTy) -> Result<IntegerValue, DiscriminantReadError> + Copy, ) -> Result<VariantId, DiscriminantReadError>
Read a discriminant from memory. The read function simulates reading an integer of the
given type at the given byte offset from memory and can return UninitByte if the byte
could not be read.