pub struct Layout {
pub size: Size,
pub align: Size,
pub discriminator: Option<Discriminator>,
pub inhabited: InhabitedPredicate,
pub variant_layouts: IndexVec<VariantId, Option<VariantLayout>>,
pub repr: ReprOptions,
}Expand description
Type layout information.
Does not include information about niches. If the type does not have a fully known layout (e.g. it is ?Sized) some of the layout parts are not available.
Fields
size: SizeThe size of the type in bytes.
align: SizeThe alignment, in bytes.
discriminator: Option<Discriminator>Decision tree that determines the active variant by reading memory. Only Some for enums.
inhabited: InhabitedPredicateWhether the type has any valid value.
Note that uninhabited types can have arbitrary layouts: (u32, !) has space for the u32
and enum E2 { A, B(!), C(i32, !) } may have space for a discriminant.
variant_layouts: IndexVec<VariantId, Option<VariantLayout>>Map from VariantId to the corresponding field layouts. Some variants don’t have a
meaningful layout due to being uninhabited (though an uninhabited variant may have a
layout). Structs and unions are modeled as having exactly one variant.
repr: ReprOptionsThe representation options of this type declaration as annotated by the user.
Implementations
Sourceimpl Layout
impl Layout
Sourcepub fn for_type(
krate: &TranslatedCrate,
kind: &TypeDeclKind,
repr: ReprOptions,
) -> Option<Self>
pub fn for_type( krate: &TranslatedCrate, kind: &TypeDeclKind, repr: ReprOptions, ) -> Option<Self>
Construct a layout for this type. The returned layout contains no size-related information.
pub fn is_variant_always_uninhabited(&self, variant_id: VariantId) -> bool
pub fn is_variant_always_inhabited(&self, variant_id: VariantId) -> bool
pub fn is_c_repr(&self) -> bool