ReprOptions

Struct ReprOptions 

pub struct ReprOptions {
    pub repr_algo: ReprAlgorithm,
    pub align_modif: Option<AlignmentModifier>,
    pub transparent: bool,
    pub explicit_discr_type: Option<IntegerTy>,
}
The representation options as annotated by the user.

NOTE: This does not include less common/unstable representations such as #[repr(simd)] or the compiler internal #[repr(linear)]. Similarly, enum discriminant representations are encoded in Variant::discriminant and Discriminator instead.

Fields

repr_algo: ReprAlgorithmalign_modif: Option<AlignmentModifier>transparent: boolexplicit_discr_type: Option<IntegerTy>

The type supplied to repr(..), if any.

Implementations

Source

impl ReprOptions

pub fn guarantees_fixed_field_order(&self) -> bool

Whether this representation options guarantee a fixed field ordering for the type.

Since we don’t support repr(simd) or repr(linear) yet, this is the case if it’s either repr(C) or an explicit discriminant type for an enum with fields (if it doesn’t have fields, this obviously doesn’t matter anyway).

Cf. https://doc.rust-lang.org/reference/type-layout.html#r-layout.repr.c.struct and https://doc.rust-lang.org/reference/type-layout.html#r-layout.repr.primitive.adt.