pub struct Size {
pub chosen: Option<SizeExpr>,
pub guarantee: Option<SizeExpr>,
}Expand description
An expression denoting a size in bytes.
Fields
chosen: Option<SizeExpr>The size chosen by this rustc run. For sized types, this is a plain integer, and for unsized
types, this is an expression describing how to compute this size based on the values found
in the pointer metadata. This can be None for polymorphic types.
guarantee: Option<SizeExpr>The guarantees about this size that can be relied on according to the Rust Reference.
Implementations